@@ -421,8 +421,8 @@ class Ansible(base.Base):
             )
         ]
         if collection_indicator in self._config.project_directory:
-            collection_path, right = self._config.project_directory.split(
-                collection_indicator
+            collection_path, right = self._config.project_directory.rsplit(
+                collection_indicator, 1
             )
             collections_path_list.append(util.abs_path(collection_path))
         collections_path_list.extend(
@@ -940,7 +940,7 @@ class Ansible(base.Base):
         )
 
         if os.environ.get("ANSIBLE_LIBRARY"):
-            paths.extend([util.abs_path(os.environ.get("ANSIBLE_LIBRARY"))])
+            paths.extend(map(util.abs_path, os.environ["ANSIBLE_LIBRARY"].split(":")))
 
         return paths
 
